/************************************************************************/
/*									*/
/*  SFSPIDemo.pde	-- Example Sketch for SFSPI		        */
/*									*/
/************************************************************************/
/*  Author:	Michelle Yu						*/
/*  Copyright (c) 2011, Digilent Inc.  	    				*/
/************************************************************************/
/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/************************************************************************/
/*  Module Description:							*/
/*									*/
/*  This sketch is an example on on how to read/write/erase a SPI serial*/
/* flash ROM with the SFSPI library      				*/	
/************************************************************************/
/*  Revision History:							*/
/*									*/
/*  08/21/2011(Michelle Yu): Created                                    */
/*									*/
/************************************************************************/
/************************************************************************/
/*  Board Support:							*/
/*									*/
/*  chipKit Uno with Pmod Shield:     Header JC	                        */
/*   (Note: To use this, download and deploy the Board Variant for      */
/*          chipKIT UNO32 W/Pmod Shield from the Digilent website)      */              
/*  Cerebot Mx3ck:                    Header JE                         */
/*  Cerebot Mx4ck:                    Header JB                         */
/*  Cerebot Mx7ck:                    Header JD                         */
/*	          Max	   SF						*/
/*  chipKit Max: Pin53 -> Pin1                                          */
/*               Pin51 -> Pin2                                          */
/*               Pin50 -> Pin3                                          */
/*               Pin52 -> Pin4                                          */
/************************************************************************/


/* ------------------------------------------------------------ */
/*		Include File Definitions			*/
/* ------------------------------------------------------------ */

#include <SFSPI.h> 
#include <DSPI.h>

/* ------------------------------------------------------------ */
/*		Local Variables					*/
/* ------------------------------------------------------------ */
SFSPI mySF;  // create servo object to control a servo 
int id, address, data, i=0;


//main program starts here 
void setup() 
{ 
  mySF.begin();
  
  Serial.begin(9600);
  
  //print the device ID
  Serial.print("Your device is the ST Microelectronics M25P");
  id = mySF.getDeviceID();
  Serial.println(id);
 
  //unprotect all area for read or write
  mySF.writeSR(0x00); 
 
 //write data 
  for(i=0; i<256; i++)
  {
     address = 0x1F0000 +i;
     
     mySF.writePage(0x6F, address);
  
     printData(address);
  }

  //erase a sector of data that the address is in
  address = 0x1F0000;
  mySF.sectorErase(address);
  Serial.println("Your data after SectorErase():");
  for(i=0; i<256; i++)
  {
     address = 0x1F0000 +i;
  
     printData(address);
  }
  
  //write data
  Serial.println("Write some data..."); 
  for(i=0; i<6; i++)
  {
     address = 0x1F0000 +i;
     
     mySF.writePage(0x6F, address);
  
     printData(address);
  }
  
 
 //erase the entire memory
  mySF.bulkErase();
  
  Serial.println("Your data after BulkErase:");
  printData(0x1F00005);
  
} 
 
void loop() 
{ 

} 

//prints data at a given address
void printData (unsigned int address)
{
    data = mySF.fastRead(address);
    Serial.print("Address 0x");
    Serial.print(address, HEX);
     Serial.print(": ");
    Serial.println(data, HEX);
}
